/* pathjumpui.hh
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2012 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef PATHJUMPUI_HH
#define PATHJUMPUI_HH

#include "wdefines.h"
#include <memory>
#include <string>
#include <list>
#include <vector>

class DeepPathStore;
class Button;
class FieldListView;
class Text;
class AGUIX;
class SolidButton;
class AContainer;

class PathJumpUI
{
public:
    PathJumpUI( AGUIX &aguix, DeepPathStore &path_store );
    ~PathJumpUI();

    int mainLoop();
    std::string getSelectedPath();

    void setCurrentDirname( const std::string &dirname );
    void setCurrentBasename( const std::string &basename );
private:
    AGUIX &m_aguix;
    DeepPathStore &m_path_store;

    std::string m_dirname, m_basename;
    std::string m_filter;
    std::string m_selected_path;
    
    std::auto_ptr<class AWindow> m_win;
    FieldListView *m_lv;
    Text *m_infixtext;
    Button *m_okb;
    Button *m_cancelb;
    AContainer *m_co1;

    typedef enum {
        PATH_HIDE,
        PATH_SHOW,
        BOOKMARK_HIDE,
        BOOKMARK_SHOW,
        BOOKMARK_MATCHED,
        BOOKMARK_FLEXIBLE_MATCHED
    } entry_visibility_t;

    std::list< std::pair< entry_visibility_t, std::string > > m_entries;
    AContainer *m_breadcrumb_co;
    std::vector< Button * > m_breadcrumb_buttons;
    int m_current_depth;
    std::vector< std::string > m_current_components;
    std::list< std::string > m_bookmarks;

    void showData();
    void maximizeWin();

    int apply_filter( const std::string &filter );
    int update_breadcrumb( const std::string &path,
                           const std::string &highlight_filter );
    int update_breadcrumb( const std::string &highlight_filter );
    int update_breadcrumb();

    void highlight_best_hit( const std::string &filter );
};

#endif
